yakumo.neutron.v2.lbaas.pool.Resource

Package yakumo :: Package neutron :: Package v2 :: Package lbaas :: Module pool :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for LBaaS Pools in Networking V2 API

Instance Methods | [hide private]
None |
update(self, name=`'``__UNDEF__``'`, lb_method=`'``__UNDEF__``'`) Update a load balancer pool | source code
None |
add_health_monitor(self, health_monitor=None) Add a health monitor into a pool | source code
None |
remove_health_monitor(self, health_monitor=None) Remove a health monitor from a pool | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| _sub_manager_list = ``{``'``health_monitor``'``:` <class 'yakumo.neutron.`...``
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, name=`'``__UNDEF__``'`, lb_method=`'``__UNDEF__``'`) | source code
Update a load balancer pool Parameters: `name` (str) - Pool name `lb_method` (str) - Load balance method ('ROUND_ROBIN', 'LEAST_CONNECTIONS' or 'SOURCE_IP') Returns: None Overrides: base.Resource.update

### add_health_monitor(self, health_monitor=None) | source code
Add a health monitor into a pool Parameters: `health_monitor` (yakumo.neutron.v2.lbaas.health_monitor.Resource) - LB health monitor (required) Returns: None

### remove_health_monitor(self, health_monitor=None) | source code
Remove a health monitor from a pool Parameters: `health_monitor` (yakumo.neutron.v2.lbaas.health_monitor.Resource) - LB health monitor (required) Returns: None

Class Variable Details | [hide private]

  ### _sub_manager_list Value:
      {'health_monitor': <class 'yakumo.neutron.v2.lbaas.health_monitor.Mana
      ger'>,
       'member': <class 'yakumo.neutron.v2.lbaas.member.Manager'>}